DynamiteAuthentication class sealed

Base dynamite authentication.

Implementers
Annotations
  • @immutable

Properties

hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, String>
The authentication headers added to a request.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheme → String?
The used authentication HTTP scheme.
final
type → String
The base type of the authentication.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited