DynamiteClient class abstract

A client for making network requests.

See:

Constructors

DynamiteClient(Uri baseURL, {Client? httpClient, List<DynamiteAuthentication>? authentications})
Creates a new dynamite network client.

Properties

authentications → List<DynamiteAuthentication>?
The available authentications for this client.
final
baseURL → Uri
The base server url used to build the request uri.
final
hashCode → int
The hash code for this object.
no setterinherited
httpClient → Client
The base http client.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited