DynamiteHttpBasicAuthentication class

Basic http authentication with username and password.

Inheritance

Constructors

DynamiteHttpBasicAuthentication({required String username, required String password})
Creates a new http basic authentication.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, String>
The authentication headers added to a request.
no setteroverride
password → String
The password.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheme → String?
The used authentication HTTP scheme.
finalinherited
type → String
The base type of the authentication.
finalinherited
username → String
The username.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited