DynamiteStatusCodeException class

An exception caused by an invalid status code in a response.

Inheritance
Implemented types

Constructors

DynamiteStatusCodeException(Response response)
Creates a new Exception from the HTTP request and response.

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
finalinherited
response → Response
The HTTP response that lead to this Exception being thrown.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode → int
The returned status code when the exception was thrown.
no setter
uri → Uri?
The URL of the HTTP request or response that failed.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited