HeaderDecoder class final

This class converts strings to serialized Header JSON objects.

Inheritance

Constructors

HeaderDecoder({required FullType specifiedType, bool explode = false})
Creates a header decoder.
const

Properties

explode → bool
Whether exploding is used for the converter.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
specifiedType → FullType
The type of the revived object.
final

Methods

bind(Stream<String> stream) → Stream<Object?>
Transforms the provided stream.
inherited
cast<RS, RT>() → Converter<RS, RT>
Provides a Converter<RS, RT> view of this stream transformer.
inherited
convert(String input) → Object?
Converts input and returns the result of the conversion.
override
fuse<TT>(Converter<Object?, TT> other) → Converter<String, TT>
Fuses this with other.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startChunkedConversion(Sink<Object?> sink) → Sink<String>
Starts a chunked conversion.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited